@@ -35,7 +35,9 @@ struct loc_network {
 	struct loc_ctx* ctx;
 	int refcount;
 
-	struct in6_addr start_address;
+	int family;
+	struct in6_addr first_address;
+	struct in6_addr last_address;
 	unsigned int prefix;
 
 	char country_code[3];
@@ -75,24 +77,22 @@ static struct in6_addr prefix_to_bitmask(unsigned int prefix) {
 	return bitmask;
 }
 
-static struct in6_addr make_start_address(const struct in6_addr* address, unsigned int prefix) {
+static struct in6_addr make_first_address(const struct in6_addr* address, const struct in6_addr* bitmask) {
 	struct in6_addr a;
-	struct in6_addr bitmask = prefix_to_bitmask(prefix);
 
 	// Perform bitwise AND
 	for (unsigned int i = 0; i < 4; i++)
-		a.s6_addr32[i] = address->s6_addr32[i] & bitmask.s6_addr32[i];
+		a.s6_addr32[i] = address->s6_addr32[i] & bitmask->s6_addr32[i];
 
 	return a;
 }
 
-static struct in6_addr make_last_address(const struct in6_addr* address, unsigned int prefix) {
+static struct in6_addr make_last_address(const struct in6_addr* address, const struct in6_addr* bitmask) {
 	struct in6_addr a;
-	struct in6_addr bitmask = prefix_to_bitmask(prefix);
 
 	// Perform bitwise OR
 	for (unsigned int i = 0; i < 4; i++)
-		a.s6_addr32[i] = address->s6_addr32[i] | ~bitmask.s6_addr32[i];
+		a.s6_addr32[i] = address->s6_addr32[i] | ~bitmask->s6_addr32[i];
 
 	return a;
 }
@@ -136,10 +136,22 @@ LOC_EXPORT int loc_network_new(struct loc_ctx* ctx, struct loc_network** network
 	n->ctx = loc_ref(ctx);
 	n->refcount = 1;
 
-	// Store the first address in the network
-	n->start_address = make_start_address(address, prefix);
+	// Store the prefix
 	n->prefix = prefix;
 
+	// Convert the prefix into a bitmask
+	struct in6_addr bitmask = prefix_to_bitmask(n->prefix);
+
+	// Store the first and last address in the network
+	n->first_address = make_first_address(address, &bitmask);
+	n->last_address = make_last_address(&n->first_address, &bitmask);
+
+	// Set family
+	if (IN6_IS_ADDR_V4MAPPED(&n->first_address))
+		n->family = AF_INET;
+	else
+		n->family = AF_INET6;
+
 	DEBUG(n->ctx, "Network allocated at %p\n", n);
 	*network = n;
 	return 0;
@@ -147,7 +159,7 @@ LOC_EXPORT int loc_network_new(struct loc_ctx* ctx, struct loc_network** network
 
 LOC_EXPORT int loc_network_new_from_string(struct loc_ctx* ctx, struct loc_network** network,
 		const char* address_string) {
-	struct in6_addr start_address;
+	struct in6_addr first_address;
 	unsigned int prefix = 0;
 	char* prefix_string;
 	int r = 1;
@@ -166,10 +178,10 @@ LOC_EXPORT int loc_network_new_from_string(struct loc_ctx* ctx, struct loc_netwo
 
 		if (prefix) {
 			// Parse the address
-			r = loc_parse_address(ctx, address_string, &start_address);
+			r = loc_parse_address(ctx, address_string, &first_address);
 
 			// Map the prefix to IPv6 if needed
-			if (IN6_IS_ADDR_V4MAPPED(&start_address))
+			if (IN6_IS_ADDR_V4MAPPED(&first_address))
 				prefix += 96;
 		}
 	}
@@ -178,7 +190,7 @@ LOC_EXPORT int loc_network_new_from_string(struct loc_ctx* ctx, struct loc_netwo
 	free(buffer);
 
 	if (r == 0) {
-		r = loc_network_new(ctx, network, &start_address, prefix);
+		r = loc_network_new(ctx, network, &first_address, prefix);
 	}
 
 	return r;
@@ -237,14 +249,13 @@ LOC_EXPORT char* loc_network_str(struct loc_network* network) {
 
 	unsigned int prefix = network->prefix;
 
-	int family = loc_network_address_family(network);
-	switch (family) {
+	switch (network->family) {
 		case AF_INET6:
-			r = format_ipv6_address(&network->start_address, string, length);
+			r = format_ipv6_address(&network->first_address, string, length);
 			break;
 
 		case AF_INET:
-			r = format_ipv4_address(&network->start_address, string, length);
+			r = format_ipv4_address(&network->first_address, string, length);
 			prefix -= 96;
 			break;
 
@@ -267,22 +278,57 @@ LOC_EXPORT char* loc_network_str(struct loc_network* network) {
 }
 
 LOC_EXPORT int loc_network_address_family(struct loc_network* network) {
-	if (IN6_IS_ADDR_V4MAPPED(&network->start_address))
-		return AF_INET;
+	return network->family;
+}
 
-	return AF_INET6;
+static char* loc_network_format_address(struct loc_network* network, const struct in6_addr* address) {
+	const size_t length = INET6_ADDRSTRLEN;
+
+	char* string = malloc(length);
+	if (!string)
+		return NULL;
+
+	int r = 0;
+
+	switch (network->family) {
+		case AF_INET6:
+			r = format_ipv6_address(address, string, length);
+			break;
+
+		case AF_INET:
+			r = format_ipv4_address(address, string, length);
+			break;
+
+		default:
+			r = -1;
+			break;
+	}
+
+	if (r) {
+		ERROR(network->ctx, "Could not format IP address to string: %s\n", strerror(errno));
+		free(string);
+
+		return NULL;
+	}
+
+	return string;
+}
+
+LOC_EXPORT char* loc_network_format_first_address(struct loc_network* network) {
+	return loc_network_format_address(network, &network->first_address);
+}
+
+LOC_EXPORT char* loc_network_format_last_address(struct loc_network* network) {
+	return loc_network_format_address(network, &network->last_address);
 }
 
 LOC_EXPORT int loc_network_match_address(struct loc_network* network, const struct in6_addr* address) {
 	// Address must be larger than the start address
-	if (in6_addr_cmp(&network->start_address, address) > 0)
+	if (in6_addr_cmp(&network->first_address, address) > 0)
 		return 1;
 
-	// Determine the last address in this network
-	struct in6_addr last_address = make_last_address(&network->start_address, network->prefix);
-
 	// Address must be smaller than the last address
-	if (in6_addr_cmp(address, &last_address) > 0)
+	if (in6_addr_cmp(&network->last_address, address) < 0)
 		return 1;
 
 	// The address is inside this network
@@ -346,6 +392,20 @@ LOC_EXPORT int loc_network_match_flag(struct loc_network* network, uint32_t flag
 	return loc_network_has_flag(network, flag);
 }
 
+LOC_EXPORT int loc_network_is_subnet_of(struct loc_network* self, struct loc_network* other) {
+	// If the start address of the other network is smaller than this network,
+	// it cannot be a subnet.
+	if (in6_addr_cmp(&self->first_address, &other->first_address) < 0)
+		return 0;
+
+	// If the end address of the other network is greater than this network,
+	// it cannot be a subnet.
+	if (in6_addr_cmp(&self->last_address, &other->last_address) > 0)
+		return 0;
+
+	return 1;
+}
+
 LOC_EXPORT int loc_network_to_database_v1(struct loc_network* network, struct loc_database_network_v1* dbobj) {
 	// Add country code
 	loc_country_code_copy(dbobj->country_code, network->country_code);
@@ -552,7 +612,7 @@ LOC_EXPORT int loc_network_tree_add_network(struct loc_network_tree* tree, struc
 	DEBUG(tree->ctx, "Adding network %p to tree %p\n", network, tree);
 
 	struct loc_network_tree_node* node = loc_network_tree_get_path(tree,
-			&network->start_address, network->prefix);
+			&network->first_address, network->prefix);
 	if (!node) {
 		ERROR(tree->ctx, "Could not find a node\n");
 		return -ENOMEM;
