@@ -316,6 +316,10 @@ static PyObject* Database_search_networks(DatabaseObject* self, PyObject* args,
 	return obj;
 }
 
+static PyObject* Database_countries(DatabaseObject* self) {
+	return Database_iterate_all(self, LOC_DB_ENUMERATE_COUNTRIES);
+}
+
 static struct PyMethodDef Database_methods[] = {
 	{
 		"get_as",
@@ -364,6 +368,13 @@ static struct PyGetSetDef Database_getsetters[] = {
 		NULL,
 		NULL,
 	},
+	{
+		"countries",
+		(getter)Database_countries,
+		NULL,
+		NULL,
+		NULL,
+	},
 	{
 		"created_at",
 		(getter)Database_get_created_at,
@@ -462,6 +473,22 @@ static PyObject* DatabaseEnumerator_next(DatabaseEnumeratorObject* self) {
 		return obj;
 	}
 
+	// Enumerate all countries
+	struct loc_country* country = NULL;
+
+	r = loc_database_enumerator_next_country(self->enumerator, &country);
+	if (r) {
+		PyErr_SetFromErrno(PyExc_ValueError);
+		return NULL;
+	}
+
+	if (country) {
+		PyObject* obj = new_country(&CountryType, country);
+		loc_country_unref(country);
+
+		return obj;
+	}
+
 	// Nothing found, that means the end
 	PyErr_SetNone(PyExc_StopIteration);
 	return NULL;
